'use strict';

define(function (require) {
  require('angular');
  require('ui/angular-bootstrap/index');

  return require('ui/modules').get('kibana', ['ui.bootstrap']).config(function ($tooltipProvider) {
    $tooltipProvider.setTriggers({ 'mouseenter': 'mouseleave click' });
  });
});
